<?php
/**
* Plugin Name: Related Portfolio
* Description: A plugin for creating a shortcode for related portfolios
* Version: 1.0
* Author: Alejandro Torres
*/

class relatedProjects {

  public function __construct() {

    add_action( 'wp_enqueue_scripts', array($this,'stylesScripts' ));
    add_shortcode( "related-portfolios", array($this,"custom_content_after_post"));
    add_shortcode( "related-products", [ $this, "custom_content_after_product" ] );

  }

  public function stylesScripts() {

    wp_enqueue_style( 'related-portfolios', plugin_dir_url( __FILE__ ) . "style.css" );

  }

  //Adding related portfolios
  public function custom_content_after_post() {

    $content = '';
    
    if ( get_post_type() == 'post' || get_post_type() == 'receta' || get_post_type() == 'diy' ) {

      /*$tags = wp_get_post_tags($post->ID);
      if ($tags) {*/

        global $post;

        $content = '<h4 class="related-portfolios-h4">'.get_post_type_object( get_post_type() )->labels->name.__(' relacionadas', 'related-portfolios').'</h4>';
        $args = array(
          'orderby' => 'rand',
          'posts_per_page' => 4,
          'post_type' => get_post_type(),
          'post__not_in' => array($post->ID)
        );
        
        // Filtering by "Plato" in case we are at recetas
        if( get_post_type() == "receta" ) {

          $plato = get_the_terms( $post->ID, 'plato' );
          if( $plato ) {
            $p = $plato[0]->term_id;

            $args['tax_query'][] = array (
                  'taxonomy' => 'plato',
                  'field' => 'term_id',
                  'terms' => $p
            );
          }
          
        }
        

        $first_tag = $tags[0]->term_id;

        $my_query = new WP_Query($args);
        if( $my_query->have_posts() ) {

          $content .= "<div class='related-portfolios-wrapper'><div class='row'>";

          while ($my_query->have_posts()) : $my_query->the_post();

          if ( has_post_thumbnail( $_post->ID ) ) {

              $featured_image = get_the_post_thumbnail( $_post->ID, 'large' );

          } else {

            $featured_image = "<img src='".get_template_directory_uri()."/assets/imgs/placeholder-gray-icon.jpg' alt='Placeholder en gris'>";

          }

          $content .=
            '<div class="col-xs-12 col-sm-6 col-md-3">
              <div>
                '.$featured_image.'
                <div class="hf-post-content">
                  <h5>'.get_the_title().'</h5>
                  '.get_the_excerpt().'
                  <br><a href="'.get_permalink().'" class="mod_bot-button style2" rel="bookmark">Leer más</a>
                  <div class="sect-corner">
                    <img src="'.get_template_directory_uri().'/assets/imgs/corner.png" alt="Esquina doblada">
                  </div>
                </div>
              </div>
            </div>';

          endwhile;
        }
        wp_reset_query();

        $content .= "</div></div>";
      //}

    }

    return $content;
  }

  public function custom_content_after_product() {
    
    $content = '';
    
    if ( get_post_type() == 'product' ) {

      global $post;

      $productRepo = new WCAldi\Repositories\ProductRepo();
      $categories = $productRepo->getProductCategories( $post->ID, true );

      $productCategoriesRepo = new WCAldi\Repositories\ProductCategoriesRepo();

      echo '<h4 class="related-products-h4"><span>' . __('También te podría interesar...', 'related-portfolios') . '</span></h4>';

      $productPromosRepo = new WCAldi\Repositories\ProductPromosRepo();
      $promos = $productPromosRepo->getProductPromos( $post->ID );
      if( !empty( $promos ) ) {
        $promo_id = null;
        $promo_slug = null;
        foreach( $promos as $p ) {
          if( $p['level'] == 2 ) {
            $promo_id = $p['id'];
            $promo_slug = $p['slug'];
          }
        }
        if( $promo_id == null ) {
          $promo_id = $promos[0]['id'];
          $promo_slug = $promos[0]['slug'];
        }
    		$promoDates = $productPromosRepo->getDateRangeBySlug( $promo_slug );
        $related_products = $productPromosRepo->getProductsInCategoriesBBDD( $promo_id , $promoDates, 3, 0, 'random');
      } else {
        $related_products = $productCategoriesRepo->getProductsCategoryBBDD( $categories[0]['id'], 3, 0, true );
      }

      if( !empty( $related_products ) ) {

        echo '<ul class="products">';
        
        foreach( $related_products as $pr ) {
          get_woocommerce_template( 'content-product-general', [ 'pr' => $pr ] );
        }
  
        echo "</ul>";

      } else {

        echo "¡Ups! No parece haber productos relacionados.";

      }

    }

  }

}

$rp = new relatedProjects();
